@@ -1,5 +1,5 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "sensei" "0.45.2"
+(define-package "sensei" "20250831.1341"
   "A client for sensei."
   '((emacs      "27.1")
     (projectile "2.5.0")
